@@ -570,3 +570,28 @@ CHIPSET(0x66A7, 0x66A7, VEGA20)
 CHIPSET(0x66AF, 0x66AF, VEGA20)
 CHIPSET(0x15dd, 0x15dd, RAVEN)
 CHIPSET(0x15d8, 0x15d8, RAVEN)
+CHIPSET(0x738C, 0x738C, ARCTURUS)
+CHIPSET(0x7388, 0x7388, ARCTURUS)
+CHIPSET(0x738E, 0x738E, ARCTURUS)
+CHIPSET(0x7390, 0x7390, ARCTURUS)
+CHIPSET(0x7310, 0x7310, NAVI10)
+CHIPSET(0x7312, 0x7312, NAVI10)
+CHIPSET(0x7318, 0x7318, NAVI10)
+CHIPSET(0x7319, 0x7319, NAVI10)
+CHIPSET(0x731A, 0x731A, NAVI10)
+CHIPSET(0x731B, 0x731B, NAVI10)
+CHIPSET(0x731E, 0x731E, NAVI10)
+CHIPSET(0x731F, 0x731F, NAVI10)
+CHIPSET(0x7340, 0x7340, NAVI14)
+CHIPSET(0x7341, 0x7341, NAVI14)
+CHIPSET(0x7347, 0x7347, NAVI14)
+CHIPSET(0x734F, 0x734F, NAVI14)
+CHIPSET(0x1636, 0x1636, RENOIR)
+CHIPSET(0x7360, 0x7360, NAVI12)
+CHIPSET(0x7362, 0x7362, NAVI12)
+CHIPSET(0x73A0, 0x73A0, SIENNA_CICHLID)
+CHIPSET(0x73A2, 0x73A2, SIENNA_CICHLID)
+CHIPSET(0x73A3, 0x73A3, SIENNA_CICHLID)
+CHIPSET(0x73AB, 0x73AB, SIENNA_CICHLID)
+CHIPSET(0x73AE, 0x73AE, SIENNA_CICHLID)
+CHIPSET(0x73BF, 0x73BF, SIENNA_CICHLID)
