@@ -18,9 +18,6 @@
 #include "radeontop.h"
 #include <getopt.h>
 
-const void *area;
-int use_ioctl;
-
 void die(const char * const why) {
 	puts(why);
 	exit(1);
@@ -33,14 +30,16 @@ static void version() {
 
 static void help(const char * const me, const unsigned int ticks, const unsigned int dumpinterval) {
 	printf(_("\n\tRadeonTop for R600 and above.\n\n"
-		"\tUsage: %s [-ch] [-b bus] [-d file] [-i seconds] [-l limit] [-t ticks]\n\n"
+		"\tUsage: %s [-chmv] [-b bus] [-d file] [-i seconds] [-l limit] [-p device] [-t ticks]\n\n"
 		"-b --bus 3		Pick card from this PCI bus (hexadecimal)\n"
 		"-c --color		Enable colors\n"
 		"-d --dump file		Dump data to this file, - for stdout\n"
 		"-i --dump-interval 1	Number of seconds between dumps (default %u)\n"
 		"-l --limit 3		Quit after dumping N lines, default forever\n"
 		"-m --mem		Force the /dev/mem path, for the proprietary driver\n"
+		"-p --path device	Open DRM device node by path\n"
 		"-t --ticks 50		Samples per second (default %u)\n"
+		"-T --transparency	Enable transparency\n"
 		"\n"
 		"-h --help		Show this help\n"
 		"-v --version		Show the version\n"),
@@ -48,32 +47,6 @@ static void help(const char * const me, const unsigned int ticks, const unsigned
 	die("");
 }
 
-int get_drm_value(int fd, unsigned request, uint32_t *out) {
-	struct drm_radeon_info info;
-	int retval;
-
-	memset(&info, 0, sizeof(info));
-
-	info.value = (unsigned long)out;
-	info.request = request;
-
-	retval = drmCommandWriteRead(fd, DRM_RADEON_INFO, &info, sizeof(info));
-	return !retval;
-}
-
-unsigned int readgrbm() {
-
-	if (use_ioctl) {
-		uint32_t reg = 0x8010;
-		get_drm_value(drm_fd, RADEON_INFO_READ_REG, &reg);
-		return reg;
-	} else {
-		const void *ptr = (const char *) area + 0x10;
-		const unsigned int *inta = ptr;
-		return *inta;
-	}
-}
-
 int main(int argc, char **argv) {
 	// Temporarily drop privileges to do option parsing, etc.
 	seteuid(getuid());
@@ -83,11 +56,14 @@ int main(int argc, char **argv) {
 
 	unsigned int ticks = default_ticks;
 	unsigned char color = 0;
-	unsigned char bus = 0, forcemem = 0;
+	unsigned char transparency = 0;
+	short bus = -1;
+	unsigned char forcemem = 0;
 	unsigned int device_id = 0;
 	unsigned int limit = 0;
 	char *dump = NULL;
 	unsigned int dumpinterval = default_dumpinterval;
+	const char *path = NULL;
 
 	// Translations
 #ifdef ENABLE_NLS
@@ -105,13 +81,15 @@ int main(int argc, char **argv) {
 		{"help", 0, 0, 'h'},
 		{"limit", 1, 0, 'l'},
 		{"mem", 0, 0, 'm'},
+		{"path", 1, 0, 'p'},
 		{"ticks", 1, 0, 't'},
+		{"transparency", 0, 0, 'T'},
 		{"version", 0, 0, 'v'},
 		{0, 0, 0, 0}
 	};
 
 	while (1) {
-		int c = getopt_long(argc, argv, "b:cd:hi:l:mt:v", opts, NULL);
+		int c = getopt_long(argc, argv, "b:cTd:hi:l:mp:t:v", opts, NULL);
 		if (c == -1) break;
 
 		switch(c) {
@@ -122,6 +100,9 @@ int main(int argc, char **argv) {
 			case 't':
 				ticks = atoi(optarg);
 			break;
+			case 'T':
+				transparency = 1;
+			break;
 			case 'c':
 				color = 1;
 			break;
@@ -145,12 +126,15 @@ int main(int argc, char **argv) {
 				if (dumpinterval < 1)
 					dumpinterval = 1;
 			break;
+			case 'p':
+				path = optarg;
+			break;
 		}
 	}
 
 	// init (regain privileges for bus initialization and ultimately drop them afterwards)
 	seteuid(0);
-	init_pci(&bus, &device_id, forcemem);
+	init_pci(path, &bus, &device_id, forcemem);
 	// after init_pci we can assume that bus/device_id exists (otherwise it would die())
 
 	setuid(getuid());
@@ -169,8 +153,8 @@ int main(int argc, char **argv) {
 	if (dump)
 		dumpdata(ticks, dump, limit, bus, dumpinterval);
 	else
-		present(ticks, cardname, color, bus, dumpinterval);
+		present(ticks, cardname, color,transparency, bus, dumpinterval);
 
-	munmap((void *) area, MMAP_SIZE);
+	cleanup();
 	return 0;
 }
